# Changelog

## [0.0.5](https://github.com/lirsacc/sloths-py/releases/tag/0.0.5) - 2025-05-14

- Drop `AsyncStream.from_iterable()`.
- Fix `AsyncStream.skip_while()`.
- Fix `AsyncStream.collect()` when called with custom collector.

## [0.0.4](https://github.com/lirsacc/sloths-py/releases/tag/0.0.4) - 2025-05-14

- Add `Stream.range()`
- Improve typing for `Stream.nth()` when default doesn't share the element type'.
- Fix `Stream.find()` for unmatched cases.
- Add `sloths.ext.asyncio` to provide an `AsyncStream` class and some common utility functions.
- Update `Stream.filter()`, `Stream.take_while()`, `Stream.skip_while()` and `Stream.find()` to support passing no predicate and filter for truthy values instead.
- Fix some incorrect information and spelling errors in the documentation.

## [0.0.3](https://github.com/lirsacc/sloths-py/releases/tag/0.0.3) - 2025-05-10

First pass released on PyPI.
